YAML (which stands for YAML Ain't a Markup Language) was designed to provide some of the same capabilities of XML
without the verboseness.  To find out more about YAML, head over to `The Official YAML Website <http://www.yaml
.org/>`_ .